"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SyntaxHighlighter = SyntaxHighlighter;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _utils = require("../utils");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const styles = _reactNative.StyleSheet.create({
  container: {
    padding: 16
  },
  line: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  }
});
function SyntaxHighlighter({
  children,
  language,
  theme,
  textStyle,
  scrollViewProps
}) {
  const [isReady, setIsReady] = (0, _react.useState)(false);
  const [tokens, setTokens] = (0, _react.useState)([]);
  const highlightCode = (0, _react.useCallback)(async () => {
    if (!(0, _utils.isLanguageRegistered)(language)) {
      console.warn(`Language "${language}" has not been registered. Please register it using registerLanguage()`);
      return;
    }
    try {
      const instance = await (0, _utils.ensureHighlighter)();
      await instance.loadTheme(theme);
      const newTokens = instance.codeToTokensBase(children, {
        theme,
        lang: language
      }).map((line, lineIndex) => line.map((token, tokenIndex) => ({
        ...token,
        id: `${lineIndex}-${tokenIndex}-${token.content}`
      })));
      setTokens(newTokens);
      setIsReady(true);
    } catch (error) {
      console.error('Failed to highlight code:', error);
    }
  }, [children, language, theme]);
  (0, _react.useEffect)(() => {
    highlightCode();
  }, [highlightCode]);
  const contentContainerStyle = (0, _react.useMemo)(() => [styles.container, scrollViewProps?.contentContainerStyle], [scrollViewProps?.contentContainerStyle]);
  if (!isReady) {
    return null;
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    ...scrollViewProps,
    horizontal: true,
    contentContainerStyle: contentContainerStyle,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      onStartShouldSetResponder: () => true,
      children: tokens.map(line => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: styles.line,
        children: line.map(token => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
          style: [textStyle, (0, _utils.getStyleForToken)(token)],
          children: token.content
        }, token.id))
      }, `line-${line.map(token => token.content).join('')}`))
    })
  });
}
//# sourceMappingURL=SyntaxHighlighter.js.map