"use strict";

import React, { useCallback, useEffect, useMemo, useState } from 'react';
import { ScrollView, StyleSheet, Text, View } from 'react-native';
import { ensureHighlighter, getStyleForToken, isLanguageRegistered } from '../utils';
import { jsx as _jsx } from "react/jsx-runtime";
const styles = StyleSheet.create({
  container: {
    padding: 16
  },
  line: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  }
});
export function SyntaxHighlighter({
  children,
  language,
  theme,
  textStyle,
  scrollViewProps
}) {
  const [isReady, setIsReady] = useState(false);
  const [tokens, setTokens] = useState([]);
  const highlightCode = useCallback(async () => {
    if (!isLanguageRegistered(language)) {
      console.warn(`Language "${language}" has not been registered. Please register it using registerLanguage()`);
      return;
    }
    try {
      const instance = await ensureHighlighter();
      await instance.loadTheme(theme);
      const newTokens = instance.codeToTokensBase(children, {
        theme,
        lang: language
      }).map((line, lineIndex) => line.map((token, tokenIndex) => ({
        ...token,
        id: `${lineIndex}-${tokenIndex}-${token.content}`
      })));
      setTokens(newTokens);
      setIsReady(true);
    } catch (error) {
      console.error('Failed to highlight code:', error);
    }
  }, [children, language, theme]);
  useEffect(() => {
    highlightCode();
  }, [highlightCode]);
  const contentContainerStyle = useMemo(() => [styles.container, scrollViewProps?.contentContainerStyle], [scrollViewProps?.contentContainerStyle]);
  if (!isReady) {
    return null;
  }
  return /*#__PURE__*/_jsx(ScrollView, {
    ...scrollViewProps,
    horizontal: true,
    contentContainerStyle: contentContainerStyle,
    children: /*#__PURE__*/_jsx(View, {
      onStartShouldSetResponder: () => true,
      children: tokens.map(line => /*#__PURE__*/_jsx(View, {
        style: styles.line,
        children: line.map(token => /*#__PURE__*/_jsx(Text, {
          style: [textStyle, getStyleForToken(token)],
          children: token.content
        }, token.id))
      }, `line-${line.map(token => token.content).join('')}`))
    })
  });
}
//# sourceMappingURL=SyntaxHighlighter.js.map