"use strict";

import { createHighlighterCore } from '@shikijs/core';
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript';

// Highlighter singleton management
let highlighter = null;
const registeredLanguages = new Map();

// Highlighter initialization
export async function ensureHighlighter() {
  if (!highlighter) {
    highlighter = await createHighlighterCore({
      themes: [],
      langs: [],
      engine: createJavaScriptRegexEngine()
    });
  }
  return highlighter;
}

// Language registration
export function registerLanguage(name, grammar) {
  if (!registeredLanguages.has(name)) {
    // Ensure all required fields are present
    const languageRegistration = {
      name,
      scopeName: grammar.scopeName || `source.${name}`,
      patterns: grammar.patterns || [],
      repository: grammar.repository || {},
      ...grammar
    };
    registeredLanguages.set(name, languageRegistration);
    if (highlighter) {
      highlighter.loadLanguageSync(languageRegistration);
    }
  }
}
export function isLanguageRegistered(name) {
  return registeredLanguages.has(name);
}
// Token styling utility
export function getStyleForToken(token) {
  const styles = {};
  if (token.color) {
    styles.color = token.color;
  }
  if (token.fontStyle) {
    if (token.fontStyle & 1) styles.fontWeight = 'bold';
    if (token.fontStyle & 2) styles.opacity = 0.5; // dim
    if (token.fontStyle & 4) styles.fontStyle = 'italic';
    if (token.fontStyle & 8) styles.textDecorationLine = 'underline';
  }
  return styles;
}
//# sourceMappingURL=index.js.map